@@ -3,6 +3,7 @@ import hashlib
 import smtplib, ssl
 import random, string, uuid
 import base64
+import time
 class login:
     ak=str(uuid.getnode())
     ake=ak.encode('utf-8')
@@ -133,9 +134,32 @@ class verify:
                         server.ehlo()  # Can be omitted
                         server.login(sender_email, password)
                         server.sendmail(sender_email, receiver_email, message)
-
+                    print('Invalid Conformation Code')
+                    sys.exit()
                 elif alert_mail=='off':
                     print('Invalid Conformation Code')
                     sys.exit()
                 else:
                     sys.exit()
+
+class Trail:
+    def trail(time, prtime):
+        now=datetime.datetime.now()
+        global te
+        te=now.strftime('%d-%m-%y %H:%M:%S')
+        lol=now.strftime('%M')
+        trailexp=(int(lol)+int(time))
+        if os.path.isfile('../../.tmp'):
+            trail=open('../../.tmp', 'r')
+            tra=trail.readlines()
+            if prtime=='on':
+                print(tra[0])
+            if te < tra[0]:
+                pass
+            else:
+                print('Trail Expire')
+                sys.exit()
+        else:
+            trail=open('../../.tmp', 'w')
+            trail.write(now.strftime('%d-%m-%y %H:')+str(trailexp))
+            trail.close()
